/*************************************************************************
*                                                                        *
*  Name : labels.h                                                       *
*                                                                        *
*  Purpose : Data Structures for Label Tables                            *
*                                                                        *
*  Author : Dr. Thomas Brandes, GMD, SCAI.WR                             *
*                                                                        *
*  Date   : 15. 4. 1993                                                  *
*                                                                        *
*************************************************************************/

# if defined __STDC__ | defined __cplusplus
# define ARGS(parameters)       parameters
# else
# define ARGS(parameters)       ()
# endif

extern void InitLabels ();

extern void NewLabel ARGS((int name, int used, int defined, int inDos));

extern void LabelDo ARGS((int label));

extern void LabelDefine ARGS((int label));
           
extern void LabelUse ARGS((int label));

extern int GetNoLabels ();

extern void GetLabelInfo ARGS((int no, int *label, int *used, int *defined));

extern int GetLabelPos ARGS((int label));

extern int GetNewLabel ();
